@@ -38,15 +38,15 @@ except Exception:
 
         @classmethod
         def warning(cls, template, cause=None, **params):
-            pass
+            print(f"WARNING: {template}")
 
         @classmethod
         def alert(cls, template, cause=None, **params):
-            print
+            print()
 
         @classmethod
         def error(cls, template, cause=None, **params):
-            raise ParseException(Null, -1, -1, msg=template, cause=cause)
+            raise ParseException(Null, -1, -1, "", msg=template, cause=cause)
 
 
 MAX_INT = sys.maxsize
@@ -379,9 +379,9 @@ def wrap_parse_action(func):
                 return result
 
             if isinstance(result, (list, tuple)):
-                return ParseResults(token.type, token.start, token.end, result)
+                return ParseResults(token.type, token.start, token.end, result, token.failures)
             else:
-                return ParseResults(token.type, token.start, token.end, [result])
+                return ParseResults(token.type, token.start, token.end, [result], token.failures)
         except ParseException as pe:
             raise pe
         except Exception as cause:
